"""Functions that extract and standardize results from `linearmodels.PanelOLS.fit()' objects."""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_linearmodels_results.ipynb.

# %% auto 0
__all__ = ['ynames', 'xnames', 'params', 'tstats', 'pvalues', 'covmat', 'se', 'nobs', 'r2']

# %% ../nbs/03_linearmodels_results.ipynb 4
import numpy as np
import pandas as pd

# %% ../nbs/03_linearmodels_results.ipynb 8
def ynames(res): return res.model.dependent.vars 

# %% ../nbs/03_linearmodels_results.ipynb 10
def xnames(res): return res.model.exog.vars

# %% ../nbs/03_linearmodels_results.ipynb 12
def params(res): return res.params

# %% ../nbs/03_linearmodels_results.ipynb 15
def tstats(res): return res.tstats

# %% ../nbs/03_linearmodels_results.ipynb 17
def pvalues(res): return res.pvalues

# %% ../nbs/03_linearmodels_results.ipynb 19
def covmat(res): return res.cov

# %% ../nbs/03_linearmodels_results.ipynb 21
def se(res): return res.std_errors

# %% ../nbs/03_linearmodels_results.ipynb 23
def nobs(res): return res.nobs

# %% ../nbs/03_linearmodels_results.ipynb 25
def r2(res): return res.rsquared
