# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/estout',
                'doc_host': 'https://ionmihai.github.io',
                'git_url': 'https://github.com/ionmihai/estout',
                'lib_path': 'estout'},
  'syms': { 'estout.core': { 'estout.core.collect_stats': ('core.html#collect_stats', 'estout/core.py'),
                             'estout.core.to_df': ('core.html#to_df', 'estout/core.py'),
                             'estout.core.to_pdf': ('core.html#to_pdf', 'estout/core.py'),
                             'estout.core.to_tex': ('core.html#to_tex', 'estout/core.py')},
            'estout.linearmodels_results': { 'estout.linearmodels_results.covmat': ( 'linearmodels_results.html#covmat',
                                                                                     'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.nobs': ( 'linearmodels_results.html#nobs',
                                                                                   'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.params': ( 'linearmodels_results.html#params',
                                                                                     'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.pvalues': ( 'linearmodels_results.html#pvalues',
                                                                                      'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.r2': ( 'linearmodels_results.html#r2',
                                                                                 'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.se': ( 'linearmodels_results.html#se',
                                                                                 'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.tstats': ( 'linearmodels_results.html#tstats',
                                                                                     'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.xnames': ( 'linearmodels_results.html#xnames',
                                                                                     'estout/linearmodels_results.py'),
                                             'estout.linearmodels_results.ynames': ( 'linearmodels_results.html#ynames',
                                                                                     'estout/linearmodels_results.py')},
            'estout.statsmodels_results': { 'estout.statsmodels_results.covmat': ( 'statsmodels_results.html#covmat',
                                                                                   'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.nobs': ( 'statsmodels_results.html#nobs',
                                                                                 'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.params': ( 'statsmodels_results.html#params',
                                                                                   'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.pvalues': ( 'statsmodels_results.html#pvalues',
                                                                                    'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.r2': ( 'statsmodels_results.html#r2',
                                                                               'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.se': ( 'statsmodels_results.html#se',
                                                                               'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.tstats': ( 'statsmodels_results.html#tstats',
                                                                                   'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.xnames': ( 'statsmodels_results.html#xnames',
                                                                                   'estout/statsmodels_results.py'),
                                            'estout.statsmodels_results.ynames': ( 'statsmodels_results.html#ynames',
                                                                                   'estout/statsmodels_results.py')},
            'estout.utils': { 'estout.utils.default_formats': ('utils.html#default_formats', 'estout/utils.py'),
                              'estout.utils.df_to_tex': ('utils.html#df_to_tex', 'estout/utils.py'),
                              'estout.utils.get_stars': ('utils.html#get_stars', 'estout/utils.py'),
                              'estout.utils.make_pdf_from_tex': ('utils.html#make_pdf_from_tex', 'estout/utils.py'),
                              'estout.utils.model_groups': ('utils.html#model_groups', 'estout/utils.py'),
                              'estout.utils.open_pdf_file': ('utils.html#open_pdf_file', 'estout/utils.py'),
                              'estout.utils.rgetattr': ('utils.html#rgetattr', 'estout/utils.py'),
                              'estout.utils.rsetattr': ('utils.html#rsetattr', 'estout/utils.py'),
                              'estout.utils.tex_table_env': ('utils.html#tex_table_env', 'estout/utils.py')}}}
